operation

package
v0.0.0-...-2097cc5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package operation provides access to the implementation of usecases of the application. Those are indepdendent of the cmd abstraction, and only deal with readily constructed dependencies and configuration. They do not know anything about command line options, or UI for the most part.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CommandAdd

func CommandAdd(deps *dependencies.Runtime, title string, dueDate string) (*repository.Entity, error)

func CommandBlock

func CommandBlock(deps *dependencies.Runtime, refs []string) ([]*repository.Entity, error)

func CommandBoost

func CommandBoost(deps *dependencies.Runtime, refs []string) ([]*repository.Entity, error)

func CommandCancel

func CommandCancel(deps *dependencies.Runtime, refs []string) ([]*repository.Entity, error)

func CommandComplete

func CommandComplete(deps *dependencies.Runtime, refs []string) ([]*repository.Entity, error)

func CommandReopen

func CommandReopen(deps *dependencies.Runtime, refs []string) ([]*repository.Entity, error)

func CommandStart

func CommandStart(deps *dependencies.Runtime, refs []string) ([]*repository.Entity, error)

func CommandTuiCapture

func CommandTuiCapture(deps *dependencies.Runtime, provided string) (*repository.Entity, error)

func QueryList

func QueryList(deps *dependencies.Runtime) ([]*repository.Entity, error)

Types

type AgendaResult

type AgendaResult struct {
	Agenda      agenda.Agenda
	Config      agenda.AgendaConfig
	TotalRanked int
}

func QueryAgenda

func QueryAgenda(deps *dependencies.Runtime) (AgendaResult, error)

Jump to