Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func UpdateToken ¶
Replaces a token's raw text and updates spans of subsequent tokens. Caller passes token index and new raw string (e.g., "@2026-04-20"). This is used to reflect changes in th tokens themselves i.e. via form fields back into the string
Types ¶
Click to show internal directories.
Click to hide internal directories.